@@ -32,7 +32,6 @@ import hubzero.config.passwords
 import hubzero.utilities.misc
 import hubzero.config.webconfig
 import hubzero.data.db
-import hubzero.utilities.hzldap
 import ldap
 
 
@@ -182,12 +181,11 @@ def _ldapGroupExists(groupName):
 	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
 	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
 	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")
-	siteSuffix = hubzero.utilities.hzldap.getLDAPSiteSuffix()
 
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
 
-	resultid = l.search(siteSuffix, ldap.SCOPE_SUBTREE, '(&(objectclass=posixGroup)(cn=' + groupName + '))', None)
+	resultid = l.search(hubLDAPBaseDN, ldap.SCOPE_SUBTREE, '(&(objectclass=posixGroup)(cn=' + groupName + '))', None)
 	result_type, result_data = l.result(resultid, 0)
 	if result_data == []:
 		return False
@@ -200,7 +198,6 @@ def addusertogroup_ldap(userName, groupName):
 	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
 	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
 	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")
-	siteSuffix = hubzero.utilities.hzldap.getLDAPSiteSuffix()
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
 	
@@ -208,7 +205,7 @@ def addusertogroup_ldap(userName, groupName):
 	mods = [(ldap.MOD_ADD, 'memberUid', userName)]
 
 	try:
-		l.modify_s('cn=' + groupName + ',ou=groups,' + siteSuffix, mods)
+		l.modify_s('cn=' + groupName + ',ou=groups,' + hubLDAPBaseDN, mods)
 	except ldap.TYPE_OR_VALUE_EXISTS:
 		pass
 
@@ -218,14 +215,13 @@ def deleteuserfromgroup_ldap(userName, groupName):
 	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
 	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
 	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")
-	siteSuffix = hubzero.utilities.hzldap.getLDAPSiteSuffix()
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
 	
 	# add the data to ldap
 	mods = [(ldap.MOD_DELETE, 'memberUid', userName)]
 
-	l.modify_s('cn=' + groupName + ',ou=groups,' + siteSuffix, mods)
+	l.modify_s('cn=' + groupName + ',ou=groups,' + hubLDAPBaseDN, mods)
 	
 
 
@@ -260,4 +256,4 @@ def getUserGroups(userName):
 	for userGroupMembership in db.query(sql, [userName]):
 		userGroupMembershipList.append(userGroupMembership.cn)
 
-	return
\ No newline at end of file
+	return
